@@ -18,7 +18,7 @@ with 'Net::Connector::Role';
 #------------------------------------------------------------------------------
 sub _buildPrompt {
   my $self   = shift;
-  my $prompt = '\@[\w\d\-\_]+(\>|\#)\s+$';
+  my $prompt = '[\w\d\-\_]+(\>|\#)\s+$';
   return $prompt;
 }
 
@@ -35,9 +35,8 @@ sub _buildCommands {
 # 具体实现 _buildErrorCode,设置命令下发错误码 -> 用于拦截配置下发
 #------------------------------------------------------------------------------
 sub _buildErrorCode {
-  my $self = shift;
-  my $codes
-    = [ 'syntax error, expecting', 'missing argument', 'unknown command', 'Invalid input detected', '^Error:', ];
+  my $self  = shift;
+  my $codes = [ 'syntax error, expecting', 'missing argument', 'unknown command', 'Invalid input detected', '^Error:', ];
   return $codes;
 }
 
