@@ -278,8 +278,7 @@ sub connect {
           $exp->send("$password\n");
         }
         else {
-          confess __PACKAGE__
-            . " case1) connect | Login ($self->{host}) failed, please provide the correct account password;";
+          confess __PACKAGE__ . " case1) connect | Login ($self->{host}) failed, please provide the correct account password;";
         }
         exp_continue();
       }
@@ -530,8 +529,7 @@ sub enable {
 
   # 异常回显信号捕捉
   if ( defined $ret[1] ) {
-    confess __PACKAGE__
-      . " case6) enable | during interactive authenticate enable password, got errors：$ret[3] . $ret[1]";
+    confess __PACKAGE__ . " case6) enable | during interactive authenticate enable password, got errors：$ret[3] . $ret[1]";
   }
 }
 
